@@ -35,7 +35,7 @@ use Exporter;
 #########################################################################
 # Setting global module variables
 #########################################################################
-$DeltaX::Database::VERSION = '3.4';				# Module version
+$DeltaX::Database::VERSION = '3.5';				# Module version
 
 #########################################################################
 # Procedure declaration
@@ -178,7 +178,14 @@ sub transaction_begin {
 		$type_f = 1;
 	}
 
-	my $result = $self->transaction_end($type_f);
+    my $result = 0;
+    if ($self->{autocommit}) {
+      if ($self->{driver} eq 'Pg') {
+        $result = $self->{conn}->begin_work();
+      }
+    } else {
+	  $result = $self->transaction_end($type_f);
+    }
 	$self->{transaction} = 1 if $result > 0;
 
 	return $result;
@@ -200,28 +207,31 @@ sub transaction_end {
 		return -2;
 	}
 	if ($self->{autocommit}) {
-		$Derror_message = "MODULE ERROR: Autocommit ON";
-		return -1;
+        if ($self->{driver} ne 'Pg') {
+  		        $Derror_message = "MODULE ERROR: Autocommit ON";
+       	    	return -1;
+        }
 	}
-
-	if ($type_f or ! $self->{transaction}) {
-		if ($self->{driver} ne 'Oracle') {
-			$result = $self->{conn}->commit;
-		}
-		else {
-			$result = $self->{conn}->do('COMMIT');
-		}
-	}
-	else {
-		if ($self->{driver} ne 'Oracle') {
-			$result = $self->{conn}->rollback if ! $type_f;
-		}
-		else {
-			$result = $self->{conn}->do('ROLLBACK');
-		}
-	}
-	$self->{transaction} = 0;
-	$self->{cursors} = {} if $self->{close_curs};
+    if (! $self->{autocommit} or $self->{transaction}) {
+        if ($type_f or ! $self->{transaction}) {
+            if ($self->{driver} ne 'Oracle') {
+                $result = $self->{conn}->commit;
+            }
+            else {
+                $result = $self->{conn}->do('COMMIT');
+            }
+        }
+        else {
+            if ($self->{driver} ne 'Oracle') {
+                $result = $self->{conn}->rollback if ! $type_f;
+            }
+            else {
+                $result = $self->{conn}->do('ROLLBACK');
+            }
+        }
+        $self->{transaction} = 0;
+        $self->{cursors} = {} if $self->{close_curs};
+    }
 
 	return 1 if $result;
 	return 0;
